@@ -3,9 +3,6 @@
 #' @importFrom utils globalVariables
 "_PACKAGE"
 
-FEDSTAT_URL_BASE <- "https://www.fedstat.ru"
-
 globalVariables(c(
-  ".",
-  FEDSTAT_URL_BASE
+  "."
 ))
